import { UIManager, Platform, Image } from 'react-native';
let MapViewManagerCommands = {
  create: 1,
  center: 2,
  setMapVenue: 3,
  centerMapOnPoint: 4,
  setFollowBlueDot: 5,
  setUserPosition: 6,
  setUserPositionXY: 7,
  clearWayfindingPath: 8,
  wayfindToWaypoint: 9,
  wayfindBetweenWaypoints: 10,
  drawNavigationPath: 11,
  styleUnitsForDestination: 12,
  styleShape: 13,
  setMapOptions: 14
  //   styleGeofences: 15,
};

if (Platform.OS == 'ios') {
  MapViewManagerCommands = {
    create: 'create',
    center: 'center',
    setMapVenue: 'setMapVenue',
    centerMapOnPoint: 'centerMapOnPoint',
    setFollowBlueDot: 'setFollowBlueDot',
    setUserPosition: 'setUserPosition',
    setUserPositionXY: 'setUserPositionXY',
    clearWayfindingPath: 'clearWayfindingPath',
    wayfindToWaypoint: 'wayfindToWaypoint',
    wayfindBetweenWaypoints: 'wayfindBetweenWaypoints',
    drawNavigationPath: 'drawNavigationPath',
    styleUnitsForDestination: 'styleUnitsForDestination',
    styleShape: 'styleShape',
    setMapOptions: 'setMapOptions'
    // styleGeofences: 'styleGeofences',
  };
}

export const createFragment = viewId => UIManager.dispatchViewManagerCommand(viewId, MapViewManagerCommands.create.toString(), [viewId]);
export const centerMap = (viewId, rotation, zoom, animationDuration) => UIManager.dispatchViewManagerCommand(viewId, MapViewManagerCommands.center.toString(), [rotation, zoom, animationDuration]);
export function getRandomInt(max) {
  return Math.floor(Math.random() * max);
}
export const setMapVenue = _ref => {
  var _mapOptions$user;
  let {
    viewId,
    credentials,
    mapOptions = {}
  } = _ref;
  console.log('Setting Map Options');
  if (mapOptions && mapOptions.user && (_mapOptions$user = mapOptions.user) !== null && _mapOptions$user !== void 0 && _mapOptions$user.iconImage) {
    console.log('Adding User Options');
    const resolvedImage = Image.resolveAssetSource(mapOptions.user.iconImage);
    mapOptions.user.iconHeight = resolvedImage.height;
    mapOptions.user.iconWidth = resolvedImage.width;
    mapOptions.user.iconUrl = resolvedImage.uri;
    console.log(mapOptions.user.iconUrl);
  }
  console.log('Map Options: ' + mapOptions);
  UIManager.dispatchViewManagerCommand(viewId, MapViewManagerCommands.setMapVenue.toString(), [credentials, mapOptions]);
};
export const setMapOptions = _ref2 => {
  var _options$user;
  let {
    viewId,
    options
  } = _ref2;
  console.log('Setting Map Options');
  if (options.user && (_options$user = options.user) !== null && _options$user !== void 0 && _options$user.iconImage) {
    console.log('Adding User Options');
    const resolvedImage = Image.resolveAssetSource(options.user.iconImage);
    options.user.iconHeight = resolvedImage.height;
    options.user.iconWidth = resolvedImage.width;
    options.user.iconUrl = resolvedImage.uri;
    console.log(options.user.iconUrl);
  }
  UIManager.dispatchViewManagerCommand(viewId, MapViewManagerCommands.setMapOptions.toString(), [options]);
};
export const centerMapOnPoint = (viewId, point) => UIManager.dispatchViewManagerCommand(viewId, MapViewManagerCommands.centerMapOnPoint.toString(), [point]);
export const setFollowBlueDot = function (viewId, enabled) {
  let rotate = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
  let interval = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 500;
  return UIManager.dispatchViewManagerCommand(viewId, MapViewManagerCommands.setFollowBlueDot.toString(), [enabled, rotate, interval]);
};
export const setUserPosition = (viewId, x, y, heading, confidence, format) => UIManager.dispatchViewManagerCommand(viewId, MapViewManagerCommands.setUserPosition.toString(), [x, y, heading, confidence, format]);
export const clearWayfindingPath = viewId => UIManager.dispatchViewManagerCommand(viewId, MapViewManagerCommands.clearWayfindingPath.toString(), []);
export const wayfindToWaypoint = (viewId, waypointId) => UIManager.dispatchViewManagerCommand(viewId, MapViewManagerCommands.wayfindToWaypoint.toString(), [waypointId]);
export const wayfindBetweenWaypoints = (viewId, originId, destinationId) => UIManager.dispatchViewManagerCommand(viewId, MapViewManagerCommands.wayfindBetweenWaypoints.toString(), [originId, destinationId]);
export const drawNavigationPath = (viewId, pathId, shouldFocus, style) => UIManager.dispatchViewManagerCommand(viewId, MapViewManagerCommands.drawNavigationPath.toString(), [pathId, shouldFocus, style]);
export const styleUnitsForDestination = (viewId, destination, style) => UIManager.dispatchViewManagerCommand(viewId, MapViewManagerCommands.styleUnitsForDestination.toString(), [destination, style]);
export const styleShape = (viewId, id, style) => UIManager.dispatchViewManagerCommand(viewId, MapViewManagerCommands.styleShape.toString(), [id, style]);

// export const styleGeofences = (
//   viewId: number | null,
//   visible: boolean,
//   style: JIBESTREAM_STYLE
// ) =>
//   UIManager.dispatchViewManagerCommand(
//     viewId,
//     MapViewManagerCommands.styleGeofences.toString(),
//     [visible, style]
//   );
//# sourceMappingURL=SendCommand.js.map